/*
 * Copyright (c) 2010-2012 The Amdatu Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.web.resourcehandler;

import java.util.List;

import org.amdatu.web.resourcehandler.webresourcekeyparser.RegisterItem;
import org.osgi.service.http.HttpContext;
import org.osgi.service.http.HttpService;
import org.osgi.service.http.NamespaceException;
import org.osgi.service.log.LogService;

public class ResourceRegister {

	private final List<RegisterItem> m_entries;
	
    private volatile HttpService m_httpService;
    private volatile HttpContext m_httpContext;
    private volatile LogService m_log;

    public ResourceRegister(List<RegisterItem> entries) {
        m_entries = entries;
    }

    /**
     * Called by Felix DM upon destruction of this component, and causes a 
     * deregistration of all registered resources.
     */
    public void destroy() {
        for (RegisterItem entry : m_entries) {
            try {
				m_httpService.unregister(entry.getAlias());
			} catch (IllegalArgumentException exception) {
                m_log.log(LogService.LOG_WARNING, "Resource deregistration failed for " + entry.getAlias() + " (" + entry.getPath() + ")", exception);
			}
        }
    }

    /**
     * Called by Felix DM upon initialization of this component, which will 
     * cause the resources to be registered.
     */
    public void init() {
        for (RegisterItem entry : m_entries) {
            try {
                m_httpService.registerResources(entry.getAlias(), entry.getPath(), m_httpContext);
            }
            catch (NamespaceException exception) {
                m_log.log(LogService.LOG_WARNING, "Resource registration failed for " + entry.getAlias() + " (" + entry.getPath() + ")", exception);
            }
        }
    }
}
