/*
 * Copyright (c) 2010-2012 The Amdatu Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.web.resourcehandler.webresourcekeyparser;

/**
 * RegisterItem contains the information to register a resource with the HttpService
 * 
 */
public class RegisterItem {

    private String m_contextId;
    private String m_alias;
    private String m_path;

    public RegisterItem(String alias) {
    	this(alias, alias);
    }

    public RegisterItem(String alias, String path) {
    	this(alias, path, "");
    }

    public RegisterItem(String alias, String path, String contextId) {
        m_alias = createValidEntry(alias.trim());
        m_path = createValidEntry(path.trim());
        m_contextId = contextId.trim();
    }

    public String getContextId() {
        return m_contextId;
    }

    public String getAlias() {
        return m_alias;
    }

    public String getPath() {
        return m_path;
    }

	private String createValidEntry(String entry) {
		if (!entry.startsWith("/")) {
			return "/" + entry;
		}
		return entry;
	}
}
