/*
 * Copyright (c) 2010-2012 The Amdatu Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.web.resourcehandler.test;

import java.util.List;
import java.util.Map;

import junit.framework.TestCase;

import org.amdatu.web.resourcehandler.webresourcekeyparser.InvalidEntryException;
import org.amdatu.web.resourcehandler.webresourcekeyparser.RegisterItem;
import org.amdatu.web.resourcehandler.webresourcekeyparser.WebResourceKeyParser;

public class WebResourseKeyParserTest extends TestCase {

	private WebResourceKeyParser m_parser = new WebResourceKeyParser();

	public void testAliasPath() throws Exception {
		String entry = "alias ; /path";
		Map<String, List<RegisterItem>> entries = m_parser.getEntries(entry);

		List<RegisterItem> list = entries.get("");
		
		assertEquals(1, list.size());
		assertEquals("/alias", list.get(0).getAlias());
		assertEquals("/path", list.get(0).getPath());
		assertEquals("", list.get(0).getContextId());
	}

	public void testNonGivenContext() throws Exception {
		String entry = "alias ; /path; ";
		Map<String, List<RegisterItem>> entries = m_parser.getEntries(entry);

		List<RegisterItem> list = entries.get("");

		assertEquals(1, list.size());
		assertEquals("/alias", list.get(0).getAlias());
		assertEquals("/path", list.get(0).getPath());
		assertEquals("", list.get(0).getContextId());
	}

	public void testEmptyContent() throws InvalidEntryException {
		String entry = ";;";

		try {
			m_parser.getEntries(entry);
			fail("Expected InvalidEntryException!");
		} catch (InvalidEntryException exception) {
			// Ok; expected...
		}
	}

	public void testEmptyContentWithSpace() throws InvalidEntryException {
		String entry = " ; ; ";
		try {
			m_parser.getEntries(entry);
			fail("Expected InvalidEntryException!");
		} catch (InvalidEntryException exception) {
			// Ok; expected...
		}
	}

	public void testFailEntry() throws InvalidEntryException {
		String entry = "path;path;path;path";

		try {
			m_parser.getEntries(entry);
			fail("Expected InvalidEntryException!");
		} catch (InvalidEntryException exception) {
			// Ok; expected...
		}
	}

	public void testMulipleContextsAndAliassesAndPaths() throws Exception {
		String entry = "bob ;path1 ; context ,jan; /path3;context3,alias ; /path, lala;path2;context,";
		
		Map<String, List<RegisterItem>> entries = m_parser.getEntries(entry);
		
		List<RegisterItem> list1 = entries.get("context");
		assertEquals(2, list1.size());
		
		RegisterItem item = list1.get(0);
		assertEquals("/bob", item.getAlias());
		assertEquals("/path1", item.getPath());

		List<RegisterItem> list2 = entries.get("");
		assertEquals(1, list2.size());
		
		item = list2.get(0);
		assertEquals("/alias", item.getAlias());
	}

	public void testNullAndEmptyEntry() throws InvalidEntryException {
		String entry = null;
		assertTrue(m_parser.getEntries(entry).isEmpty());
		entry = "";
		assertTrue(m_parser.getEntries(entry).isEmpty());
	}

	public void testSingleAlias() throws Exception {
		Map<String, List<RegisterItem>> entries = m_parser.getEntries("path");
		
		assertEquals("/path", entries.get("").get(0).getAlias());
		
		entries = m_parser.getEntries("/path");

		assertEquals("/path", entries.get("").get(0).getAlias());
	}
}
